
#include <windows.h>
#include "..\acroauto.h"

extern void FAR PASCAL Kevin2();     
int PASCAL WinMain(hInstance, hPrevInstance, lpCmdLine, nCmdShow)
HANDLE hInstance;            
HANDLE hPrevInstance;        
char *lpCmdLine;             
int nCmdShow;                
{
	HACROAUTO hAcroAuto;
	HACROAPP hAcroApp; 

	// For Ole 2.0 programs, it is recommended that the line
	// SetMessageQueue(96) be places in you WinMain or InitInstance
	// code.  This line will clear the current message queue, so do it early
	SetMessageQueue(96);
	hAcroAuto = AcroAutoInitialize();
	if (!hAcroAuto) return FALSE;     
	hAcroApp = AcroAppNew();
	if (!hAcroApp) goto error;
	
	AcroAppShow(hAcroApp);
	
	AcroAppDelete(hAcroApp);
	
	AcroAutoUninitialize(hAcroAuto);
	return TRUE;
	
error:
	AcroAutoUninitialize(hAcroAuto);
	return FALSE;
} 
     
     
